@@ -2,8 +2,6 @@
 from dash import Dash, page_container, html, dcc
 import dash_bootstrap_components as dbc
 
-# SageWorks Imports
-
 
 # Note: The 'app' and 'server' objects need to be at the top level since NGINX/uWSGI needs to
 #       import this file and use the server object as an ^entry-point^ into the Dash Application Code
@@ -28,5 +26,5 @@ app.layout = html.Div(
 if __name__ == "__main__":
     """Run our web application in TEST mode"""
     # Note: This 'main' is purely for running/testing locally
-    # app.run_server(host="0.0.0.0", port=8000, debug=True)
-    app.run_server(host="0.0.0.0", port=8000)
+    # app.run_server(host="0.0.0.0", port=8000, debug=True, dev_tools_ui=False, dev_tools_props_check=False)
+    app.run_server(host="0.0.0.0", port=8000, dev_tools_ui=False, dev_tools_props_check=False)
