@@ -5,10 +5,6 @@ import logging
 
 # SageWorks Imports
 from sageworks.aws_service_broker.aws_account_clamp import AWSAccountClamp
-from sageworks.utils.sageworks_logging import logging_setup
-
-# Setup Logging
-logging_setup()
 
 
 class AWSIdentityCheck:
