@@ -4,26 +4,21 @@ import sys
 import argparse
 from enum import Enum, auto
 import logging
-from threading import Thread
+from concurrent.futures import ThreadPoolExecutor
 from botocore.exceptions import ClientError
 
 # SageWorks Imports
-from sageworks.utils.cache import Cache
-from sageworks.utils.redis_cache import RedisCache
+from sageworks.utils.sageworks_cache import SageWorksCache
 from sageworks.aws_service_broker.aws_service_connectors.s3_bucket import S3Bucket
 from sageworks.aws_service_broker.aws_service_connectors.glue_jobs import GlueJobs
 from sageworks.aws_service_broker.aws_service_connectors.data_catalog import DataCatalog
-from sageworks.aws_service_broker.aws_service_connectors.feature_store import (
-    FeatureStore,
-)
-from sageworks.aws_service_broker.aws_service_connectors.model_registry import (
-    ModelRegistry,
-)
+from sageworks.aws_service_broker.aws_service_connectors.feature_store import FeatureStore
+from sageworks.aws_service_broker.aws_service_connectors.model_registry import ModelRegistry
 from sageworks.aws_service_broker.aws_service_connectors.endpoints import Endpoints
-from sageworks.utils.sageworks_logging import logging_setup
 
-# Setup Logging
-logging_setup()
+
+# SageWorks Logger
+log = logging.getLogger("sageworks")
 
 
 # Enumerated types for SageWorks Meta Requests
@@ -50,7 +45,7 @@ class AWSServiceBroker:
     def __new__(cls):
         """AWSServiceBroker Singleton Pattern"""
         if not hasattr(cls, "instance"):
-            print("Creating New AWSServiceBroker Instance...")
+            log.info("Creating the AWSServiceBroker Singleton...")
             cls.instance = super(AWSServiceBroker, cls).__new__(cls)
 
             # Class Initialization
@@ -91,15 +86,13 @@ class AWSServiceBroker:
         cls.model_registry = ModelRegistry()
         cls.endpoints = Endpoints()
 
-        # Cache for Metadata
-        if RedisCache().check():
-            cls.meta_cache = RedisCache()
-            cls.fresh_cache = RedisCache(expire=20, postfix=":fresh")
-            cls.open_threads = []
-        else:
-            cls.meta_cache = Cache()
-            cls.fresh_cache = Cache(expire=20)
-            cls.open_threads = []
+        # Caches for Metadata
+        cls.meta_cache = SageWorksCache()
+        cls.fresh_cache = SageWorksCache(expire=60, postfix=":fresh")
+
+        # Thread Pool for Refreshes
+        # Note: We only need 1 thread for data refreshes, a bunch of threads = AWS Throttling
+        cls.thread_pool = ThreadPoolExecutor(max_workers=1)
 
         # This connection map sets up the connector objects for each category of metadata
         # Note: Even though this seems confusing, it makes other code WAY simpler
@@ -123,11 +116,12 @@ class AWSServiceBroker:
         """
         # Refresh the connection for the given category and pull new data
         try:
+            cls.fresh_cache.set(category, True)
             cls.connection_map[category].refresh()
             cls.meta_cache.set(category, cls.connection_map[category].aws_meta())
-            cls.fresh_cache.set(category, True)
-        except ClientError as e:
-            cls.log.warning(f"Failed to refresh AWS data for {category}: {e}")
+        except ClientError:
+            cls.log.warning(f"Failed to refresh AWS data for {category}")
+            cls.log.warning("Sometimes this happens when an artifact is being deleted/recreated...")
 
     @classmethod
     def get_metadata(cls, category: ServiceCategory, force_refresh: bool = False) -> dict:
@@ -156,15 +150,16 @@ class AWSServiceBroker:
 
         # Is the AWS data stale?
         if cls.fresh_cache.get(category) is None:
-            cls.log.info(f"Async: Metadata for {category} is stale, launching refresh thread...")
+            cls.log.debug(f"Async: Metadata for {category} is stale, launching refresh thread...")
             cls.fresh_cache.set(category, True)
-            thread = Thread(target=cls.refresh_aws_data, args=(category,))
-            cls.open_threads.append(thread)
-            thread.start()
+
+            # Submit the data refresh task to the thread pool
+            cls.thread_pool.submit(cls.refresh_aws_data, category)
+
+            # Return the stale data
             return cls.meta_cache.get(category)
 
         # If the metadata is fresh, just return it
-        cls.log.debug(f"Metadata for {category} is fresh!")
         return cls.meta_cache.get(category)
 
     @classmethod
@@ -175,14 +170,13 @@ class AWSServiceBroker:
         Returns:
             dict: The Metadata for ALL the Service Categories
         """
-        cls.log.info("Getting ALL AWS Metadata: You should call get_metadata() with specific categories")
+        cls.log.info(f"Getting ALL AWS Metadata...(force_refresh={force_refresh})")
         return {_category: cls.get_metadata(_category, force_refresh) for _category in ServiceCategory}
 
     @classmethod
-    def wait_for_refreshes(cls) -> None:
-        """Wait for any open threads to finish"""
-        for thread in cls.open_threads:
-            thread.join()
+    def shutdown(cls) -> None:
+        """Wait for any open threads in our thread pool to finish"""
+        cls.thread_pool.shutdown(wait=True)
 
     @classmethod
     def get_s3_object_sizes(cls, category: ServiceCategory, prefix: str = "") -> int:
@@ -231,10 +225,6 @@ if __name__ == "__main__":
     # NOTE: There should be NO Refreshes in the logs
     pprint(aws_broker.get_all_metadata())
 
-    # Get the Metadata for ALL the categories
-    # NOTE: This should force a refresh of the metadata
-    # pprint(aws_broker.get_all_metadata(force_refresh=True))
-
     # Get S3 object sizes
     incoming_data_size = aws_broker.get_s3_object_sizes(ServiceCategory.INCOMING_DATA_S3)
     print(f"Incoming Data Size: {incoming_data_size} Bytes")
@@ -246,4 +236,4 @@ if __name__ == "__main__":
     print(f"Abalone Size: {abalone_size} Bytes")
 
     # Wait for any open threads to finish
-    aws_broker.wait_for_refreshes()
+    aws_broker.shutdown()
