@@ -6,10 +6,7 @@ from typing import final
 
 # SageWorks Imports
 from sageworks.aws_service_broker.aws_account_clamp import AWSAccountClamp
-from sageworks.utils.sageworks_logging import logging_setup
-
-# Set up logging
-logging_setup()
+from sageworks.utils.aws_utils import list_tags_with_throttle
 
 
 class Connector(ABC):
@@ -49,17 +46,11 @@ class Connector(ABC):
         """Return ALL the AWS metadata for this AWS Service"""
         pass
 
-    @staticmethod
-    def _aws_tags_to_dict(aws_tags) -> dict:
-        """Internal: AWS Tags are in an odd format, so convert to regular dictionary"""
-        return {item["Key"]: item["Value"] for item in aws_tags}
-
     def sageworks_meta_via_arn(self, arn: str) -> dict:
         """Helper: Get the SageWorks specific metadata for this ARN
-        Note: This functionality is a helper or Feature Store, Models, and Endpoints.
-              The Data Catalog and Glue Jobs class have their own methods/logic
+        Args:
+            arn (str): The ARN of the SageMaker resource
+        Returns:
+            dict: A dictionary of SageWorks specific metadata
         """
-        self.log.info(f"Retrieving SageWorks Metadata for Artifact: {arn}...")
-        aws_tags = self.sm_session.list_tags(arn)
-        meta = self._aws_tags_to_dict(aws_tags)
-        return meta
+        return list_tags_with_throttle(arn, self.sm_session)
