@@ -40,8 +40,13 @@ class DataCatalog(Connector):
 
         # For each database in our scoped list, load the tables
         for database in self.scoped_database_list:
-            print(f"Reading Data Catalog Database: {database}...")
-            table_list = wr.catalog.get_tables(database=database, boto3_session=self.boto_session)
+            # Get all table metadata from the Glue catalog Database
+            self.log.debug(f"Reading Data Catalog Database: {database}...")
+            all_tables = wr.catalog.get_tables(database=database, boto3_session=self.boto_session)
+
+            # Filter out views (disabled for now)
+            table_list = all_tables
+            # table_list = [table for table in all_tables if table["TableType"] in ("EXTERNAL_TABLE", "MANAGED_TABLE")]
 
             # Convert to a data structure with direct lookup
             self.data_catalog_metadata[database] = {table["Name"]: table for table in table_list}
