@@ -5,11 +5,7 @@ import logging
 
 # Local Imports
 from sageworks.aws_service_broker.aws_account_clamp import AWSAccountClamp
-from sageworks.transforms.transform import TransformOutput as ArtifactType
-from sageworks.utils.sageworks_logging import logging_setup
-
-# Setup Logging
-logging_setup()
+from sageworks.core.transforms.transform import TransformOutput as ArtifactType
 
 
 class SageWorksEventBridge:
