@@ -1,30 +1,31 @@
 """ArtifactsTextView pulls All the metadata from the AWS Service Broker and organizes/summarizes it"""
 import json
 import pandas as pd
+from datetime import datetime
 from termcolor import colored
+from typing import Dict
 
 # SageWorks Imports
 from sageworks.views.view import View
 from sageworks.aws_service_broker.aws_service_broker import ServiceCategory
-from sageworks.artifacts.data_sources.data_source import DataSource
-from sageworks.artifacts.feature_sets.feature_set import FeatureSet
-from sageworks.artifacts.models.model import Model
-from sageworks.artifacts.endpoints.endpoint import Endpoint
+from sageworks.utils.iso_8601 import iso8601_to_datetime
 
 
 class ArtifactsTextView(View):
+    aws_artifact_data = None  # Class-level attribute for caching the AWS Artifact Data
+
     def __init__(self):
         """ArtifactsTextView pulls All the metadata from the AWS Service Broker and organizes/summarizes it"""
         # Call SuperClass Initialization
         super().__init__()
 
         # Get AWS Service information for ALL the categories (data_source, feature_set, endpoints, etc)
-        self.aws_artifact_data = self.aws_broker.get_all_metadata()
+        if ArtifactsTextView.aws_artifact_data is None:
+            ArtifactsTextView.aws_artifact_data = self.aws_broker.get_all_metadata()
 
         # Setup Pandas output options
-        pd.set_option("display.max_colwidth", 50)
-        pd.set_option("display.max_columns", 15)
-        pd.set_option("display.width", 1000)
+        pd.set_option("display.max_colwidth", 35)
+        pd.set_option("display.width", 600)
 
     def check(self) -> bool:
         """Can we connect to this view/service?"""
@@ -32,9 +33,9 @@ class ArtifactsTextView(View):
 
     def refresh(self, force_refresh: bool = False) -> None:
         """Refresh data/metadata associated with this view"""
-        self.aws_artifact_data = self.aws_broker.get_all_metadata(force_refresh=force_refresh)
+        ArtifactsTextView.aws_artifact_data = self.aws_broker.get_all_metadata(force_refresh=force_refresh)
 
-    def view_data(self) -> dict:
+    def view_data(self) -> Dict[str, pd.DataFrame]:
         """Get all the data that's useful for this view
 
         Returns:
@@ -79,7 +80,7 @@ class ArtifactsTextView(View):
 
     def incoming_data_summary(self) -> pd.DataFrame:
         """Get summary data about data in the incoming-data S3 Bucket"""
-        data = self.aws_artifact_data[ServiceCategory.INCOMING_DATA_S3]
+        data = ArtifactsTextView.aws_artifact_data[ServiceCategory.INCOMING_DATA_S3]
         if data is None:
             print("No incoming-data S3 Bucket Found! Please set your SAGEWORKS_BUCKET ENV var!")
             return pd.DataFrame(
@@ -119,7 +120,7 @@ class ArtifactsTextView(View):
 
     def glue_jobs_summary(self) -> pd.DataFrame:
         """Get summary data about AWS Glue Jobs"""
-        glue_meta = self.aws_artifact_data[ServiceCategory.GLUE_JOBS]
+        glue_meta = ArtifactsTextView.aws_artifact_data[ServiceCategory.GLUE_JOBS]
         glue_summary = []
 
         # Get the information about each Glue Job
@@ -154,7 +155,7 @@ class ArtifactsTextView(View):
 
     def data_sources_summary(self) -> pd.DataFrame:
         """Get summary data about the SageWorks DataSources"""
-        data_catalog = self.aws_artifact_data[ServiceCategory.DATA_CATALOG]
+        data_catalog = ArtifactsTextView.aws_artifact_data[ServiceCategory.DATA_CATALOG]
         data_summary = []
 
         # Get the SageWorks DataSources
@@ -170,7 +171,7 @@ class ArtifactsTextView(View):
                     "Name": name,
                     "Size(MB)": size,
                     "Modified": self.datetime_string(info.get("UpdateTime")),
-                    "Num Columns": self.num_columns(info),
+                    "Num Columns": self.num_columns_ds(info),
                     "DataLake": info.get("IsRegisteredWithLakeFormation", "-"),
                     "Tags": info.get("Parameters", {}).get("sageworks_tags", "-"),
                     "Input": str(
@@ -198,7 +199,7 @@ class ArtifactsTextView(View):
 
     def feature_sets_summary(self) -> pd.DataFrame:
         """Get summary data about the SageWorks FeatureSets"""
-        data = self.aws_artifact_data[ServiceCategory.FEATURE_STORE]
+        data = ArtifactsTextView.aws_artifact_data[ServiceCategory.FEATURE_STORE]
         data_summary = []
         for feature_group, group_info in data.items():
             # Get the SageWorks metadata for this Feature Group
@@ -214,12 +215,12 @@ class ArtifactsTextView(View):
             summary = {
                 "Feature Group": group_info["FeatureGroupName"],
                 "Size(MB)": size,
-                "Catalog DB": cat_config.get("Database", "-").lower(),
-                "Athena Table": cat_config.get("TableName", "-"),
-                "Online": str(group_info.get("OnlineStoreConfig", {}).get("EnableOnlineStore", "False")),
                 "Created": self.datetime_string(group_info.get("CreationTime")),
-                "Tags": sageworks_meta.get("sageworks_tags", "-"),
+                "Num Columns": self.num_columns_fs(group_info),
                 "Input": sageworks_meta.get("sageworks_input", "-"),
+                "Tags": sageworks_meta.get("sageworks_tags", "-"),
+                "Online": str(group_info.get("OnlineStoreConfig", {}).get("EnableOnlineStore", "False")),
+                "Athena Table": cat_config.get("TableName", "-"),
                 "_aws_url": self.aws_url(group_info, "FeatureSet"),  # Hidden Column
             }
             data_summary.append(summary)
@@ -231,40 +232,54 @@ class ArtifactsTextView(View):
             columns = [
                 "Feature Group",
                 "Size(MB)",
-                "Catalog DB",
-                "Athena Table",
-                "Online",
                 "Created",
-                "Tags",
+                "Num Columns",
                 "Input",
+                "Tags",
+                "Online",
+                "Athena Table",
                 "_aws_url",
             ]
             return pd.DataFrame(columns=columns)
 
     def models_summary(self) -> pd.DataFrame:
         """Get summary data about the SageWorks Models"""
-        data = self.aws_artifact_data[ServiceCategory.MODELS]
+        data = ArtifactsTextView.aws_artifact_data[ServiceCategory.MODELS]
         model_summary = []
-        for model_group_info, model_list in data.items():
+        for model_group_name, model_list in data.items():
             # Special Case for Model Groups without any Models
             if not model_list:
-                summary = {"Model Group": model_group_info}
+                summary = {
+                    "Model Group": model_group_name,
+                    "Health": "No Models!",
+                    "Created": "-",
+                    "Ver": "-",
+                    "Tags": "-",
+                    "Input": "-",
+                    "Status": "Empty",
+                    "Description": "-",
+                }
                 model_summary.append(summary)
                 continue
 
-            # Get Summary information for each model in the model_list
-            for model in model_list:
-                # Get the SageWorks metadata for this Model Group
-                sageworks_meta = model.get("sageworks_meta", {})
-                summary = {
-                    "Model Group": model["ModelPackageGroupName"],
-                    "Status": model["ModelPackageStatus"],
-                    "Description": model["ModelPackageDescription"],
-                    "Created": self.datetime_string(model.get("CreationTime")),
-                    "Tags": sageworks_meta.get("sageworks_tags", "-"),
-                    "Input": sageworks_meta.get("sageworks_input", "-"),
-                }
-                model_summary.append(summary)
+            # Get Summary information for the 'latest' model in the model_list
+            latest_model = model_list[0]
+            sageworks_meta = latest_model.get("sageworks_meta", {})
+
+            # If the sageworks_health_tags have nothing in them, then the model is healthy
+            health_tags = sageworks_meta.get("sageworks_health_tags", "-")
+            health_tags = health_tags if health_tags else "healthy"
+            summary = {
+                "Model Group": latest_model["ModelPackageGroupName"],
+                "Health": health_tags,
+                "Created": self.datetime_string(latest_model.get("CreationTime")),
+                "Ver": latest_model["ModelPackageVersion"],
+                "Tags": sageworks_meta.get("sageworks_tags", "-"),
+                "Input": sageworks_meta.get("sageworks_input", "-"),
+                "Status": latest_model["ModelPackageStatus"],
+                "Description": latest_model.get("ModelPackageDescription", "-"),
+            }
+            model_summary.append(summary)
 
         # Make sure we have data else return just the column names
         if model_summary:
@@ -272,17 +287,19 @@ class ArtifactsTextView(View):
         else:
             columns = [
                 "Model Group",
-                "Status",
-                "Description",
+                "Health",
                 "Created",
+                "Ver",
                 "Tags",
                 "Input",
+                "Status",
+                "Description",
             ]
             return pd.DataFrame(columns=columns)
 
     def endpoints_summary(self) -> pd.DataFrame:
         """Get summary data about the SageWorks Endpoints"""
-        data = self.aws_artifact_data[ServiceCategory.ENDPOINTS]
+        data = ArtifactsTextView.aws_artifact_data[ServiceCategory.ENDPOINTS]
         data_summary = []
 
         # Get Summary information for each endpoint
@@ -290,14 +307,20 @@ class ArtifactsTextView(View):
             # Get the SageWorks metadata for this Endpoint
             sageworks_meta = endpoint_info.get("sageworks_meta", {})
 
+            # If the sageworks_health_tags have nothing in them, then the endpoint is healthy
+            health_tags = sageworks_meta.get("sageworks_health_tags", "-")
+            health_tags = health_tags if health_tags else "healthy"
             summary = {
                 "Name": endpoint_info["EndpointName"],
-                "Status": endpoint_info["EndpointStatus"],
+                "Health": health_tags,
+                "Instance": endpoint_info.get("InstanceType", "-"),
                 "Created": self.datetime_string(endpoint_info.get("CreationTime")),
-                "DataCapture": str(endpoint_info.get("DataCaptureConfig", {}).get("EnableCapture", "False")),
-                "Sampling(%)": str(endpoint_info.get("DataCaptureConfig", {}).get("CurrentSamplingPercentage", "-")),
                 "Tags": sageworks_meta.get("sageworks_tags", "-"),
                 "Input": sageworks_meta.get("sageworks_input", "-"),
+                "Status": endpoint_info["EndpointStatus"],
+                "Variant": endpoint_info.get("ProductionVariants", [{}])[0].get("VariantName", "-"),
+                "Capture": str(endpoint_info.get("DataCaptureConfig", {}).get("EnableCapture", "False")),
+                "Samp(%)": str(endpoint_info.get("DataCaptureConfig", {}).get("CurrentSamplingPercentage", "-")),
             }
             data_summary.append(summary)
 
@@ -307,17 +330,20 @@ class ArtifactsTextView(View):
         else:
             columns = [
                 "Name",
-                "Status",
+                "Health",
+                "Instance",
                 "Created",
-                "DataCapture",
-                "Sampling(%)",
                 "Tags",
                 "Input",
+                "Status",
+                "Variant",
+                "Capture",
+                "Samp(%)",
             ]
             return pd.DataFrame(columns=columns)
 
     @staticmethod
-    def num_columns(data_info):
+    def num_columns_ds(data_info):
         """Helper: Compute the number of columns from the storage descriptor data"""
         try:
             return len(data_info["StorageDescriptor"]["Columns"])
@@ -325,12 +351,39 @@ class ArtifactsTextView(View):
             return "-"
 
     @staticmethod
-    def datetime_string(datetime_obj):
-        """Helper: Convert DateTime Object into a nice string"""
-        if datetime_obj is None or datetime_obj == "-":
+    def num_columns_fs(data_info):
+        """Helper: Compute the number of columns from the feature group data"""
+        try:
+            return len(data_info["FeatureDefinitions"])
+        except KeyError:
             return "-"
-        # Date + Hour Minute
-        return datetime_obj.strftime("%Y-%m-%d %H:%M")
+
+    def datetime_string(self, datetime_obj: datetime) -> str:
+        """Helper: Convert DateTime Object into a nicely formatted string.
+
+        Args:
+            datetime_obj (datetime): The datetime object to convert.
+
+        Returns:
+            str: The datetime as a string in the format "YYYY-MM-DD HH:MM", or "-" if input is None or "-".
+        """
+        placeholder = "-"
+        if datetime_obj is None or datetime_obj == placeholder:
+            return placeholder
+
+        if not isinstance(datetime_obj, datetime):
+            self.log.debug("Expected datetime object.. trying to convert...")
+            try:
+                datetime_obj = iso8601_to_datetime(datetime_obj)
+            except Exception as e:
+                self.log.error(f"Failed to convert datetime object: {e}")
+                return str(datetime_obj)
+
+        try:
+            return datetime_obj.strftime("%Y-%m-%d %H:%M")
+        except Exception as e:
+            self.log.error(f"Failed to convert datetime to string: {e}")
+            return str(datetime_obj)
 
     def aws_url(self, artifact_info, artifact_type):
         """Helper: Try to extract the AWS URL from the Artifact Info Object"""
@@ -356,25 +409,6 @@ class ArtifactsTextView(View):
             # Hack for constraints on the SageMaker Feature Group Tags
             return aws_url.replace("__question__", "?").replace("__pound__", "#")
 
-    @staticmethod
-    def delete_artifact(artifact_uuid: str):
-        """Delete a SageWorks Artifact
-        Args:
-            artifact_uuid (str): The UUID of the SageWorks Artifact to delete
-        """
-        # Note: This logic can certainly be improved, right now
-        # we are simply searching for the artifact_uuid in each
-        # of the artifact types and deleting it if found.
-        # This is not ideal because it is possible to have
-        # multiple artifacts with the same UUID.
-        for artifact_class in [Endpoint, Model, FeatureSet, DataSource]:
-            print(f"Checking {artifact_class.__name__} {artifact_uuid}...")
-            artifact = artifact_class(artifact_uuid)
-            if artifact.exists():
-                print(f"Deleting {artifact_class.__name__} {artifact_uuid}...")
-                artifact.delete()
-                return
-
 
 if __name__ == "__main__":
     import time
@@ -388,8 +422,5 @@ if __name__ == "__main__":
     # Give a text summary of all the Artifacts in the AWS Account
     artifacts.summary()
 
-    # Create and then delete a specific artifact
-    artifacts.delete_artifact("test_data")
-
     # Give any broker threads time to finish
-    time.sleep(1)
+    time.sleep(2)
