@@ -19,8 +19,8 @@ class Table(ComponentInterface):
         component_id: str,
         header_color="rgb(60, 60, 60)",
         row_select=False,
-        max_height: str = "200px",
-        fixed_headers: bool = False,
+        max_height: int = 200,
+        fixed_headers: bool = True,
     ) -> dash_table.DataTable:
         """Create a DataTable Component without any data.
         Args:
@@ -48,26 +48,28 @@ class Table(ComponentInterface):
                 "padding": "5px",
                 "overflow": "hidden",
                 "textOverflow": "ellipsis",
+                "minWidth": 80,
                 "maxWidth": 250,
                 "textAlign": "left",
             },
             style_header={
+                "className": "dash-table-header",
                 "textAlign": "left",
-                "fontSize": 16,
+                "fontSize": 14,
+                "padding": "5px 5px 5px 5px",
                 "backgroundColor": header_color,
+                "backgroundImage": f"linear-gradient(to bottom, {header_color}, rgba(0, 0, 0, 0.5))",
                 "color": "rgb(200, 200, 200)",
+                "border": "0px",
             },
             style_data={
-                "fontSize": 14,
+                "fontSize": 13,
                 "backgroundColor": "rgba(60, 60, 60, 0.5)",
                 "color": "rgb(200, 200, 200)",
                 "border": "0px",
             },
+            style_data_conditional=[{"if": {"column_id": "Health"}, "fontSize": 16, "textAlign": "left"}],
             markdown_options={"html": True},
-            style_header_conditional=[{"if": {"column_id": "del"}, "color": "transparent"}],
-            style_cell_conditional=[
-                {"if": {"column_id": "del"}, "padding": "7px 0px 0px 0px"},
-            ],
         )
         return table
 
@@ -88,6 +90,7 @@ class Table(ComponentInterface):
             "id",
             "uuid",
             "write_time",
+            "event_time",
             "api_invocation_time",
             "is_deleted",
             "x",
@@ -98,22 +101,25 @@ class Table(ComponentInterface):
         if not show_columns:
             show_columns = [c for c in df.columns.to_list() if c not in dont_show]
 
-        # Column Setup with name, id, and presentation type
         column_setup_list = []
         for c in show_columns:
-            presentation = "markdown" if markdown_columns and c in markdown_columns else "input"
-            # Check for a numeric column
+            column_def = {
+                "name": c,
+                "id": c,
+                "presentation": "markdown" if markdown_columns and c in markdown_columns else "input",
+            }
+
+            # Check for a numeric column and add additional properties as needed
             if df[c].dtype in ["float64", "float32"]:
-                column_setup_list.append(
+                column_def.update(
                     {
-                        "name": c,
-                        "id": c,
                         "type": "numeric",
                         "format": Format(group=",", precision=3, scheme="f"),
                     }
                 )
-            else:
-                column_setup_list.append({"name": c, "id": c, "presentation": presentation})
+
+            column_setup_list.append(column_def)
+
         return column_setup_list
 
     @staticmethod
@@ -149,3 +155,29 @@ class Table(ComponentInterface):
             ]
 
         return style_cells
+
+
+if __name__ == "__main__":
+    from dash import Dash, html
+    from sageworks.api.data_source import DataSource
+
+    # Get a smart sample from a test data source
+    ds = DataSource("abalone_data")
+    df = ds.smart_sample()
+
+    app = Dash(__name__)
+    my_table = Table()
+    table_comp = my_table.create_component("test-table")
+
+    # Testing HTML Links
+    columns = df.columns.to_list()
+    df["Name"] = df.index
+    df = df[["Name"] + columns]
+    df["Name"] = df["Name"].map(lambda x: f"<a href='https://www.google.com' target='_blank'>{x}</a>")
+
+    table_comp.columns = my_table.column_setup(df, markdown_columns=["Name"])
+    table_comp.data = df.to_dict("records")
+    app.layout = html.Div([table_comp])
+
+    if __name__ == "__main__":
+        app.run(debug=True)
