@@ -1,15 +1,15 @@
 """Tests for the Endpoint functionality"""
 
 # SageWorks Imports
-from sageworks.artifacts.endpoints.endpoint import Endpoint
+from sageworks.core.artifacts.endpoint_core import EndpointCore
 
 
 def test():
     """Simple test of the Endpoint functionality"""
-    from sageworks.transforms.pandas_transforms.features_to_pandas import FeaturesToPandas
+    from sageworks.core.transforms.pandas_transforms.features_to_pandas import FeaturesToPandas
 
     # Grab an Endpoint object and pull some information from it
-    my_endpoint = Endpoint("abalone-regression-end")
+    my_endpoint = EndpointCore("abalone-regression-end")
 
     # Call the various methods
 
@@ -24,7 +24,7 @@ def test():
     print(f"Tags: {my_endpoint.sageworks_tags()}")
 
     # Create the FeatureSet to DF Transform
-    feature_to_pandas = FeaturesToPandas("abalone_feature_set")
+    feature_to_pandas = FeaturesToPandas("abalone_features")
 
     # Transform the DataSource into a Pandas DataFrame (with max_rows = 100)
     feature_to_pandas.transform(max_rows=100)
@@ -40,8 +40,7 @@ def test():
     # Compute performance metrics for our test predictions
     target_column = "class_number_of_rings"
     metrics = my_endpoint.regression_metrics(target_column, result_df)
-    for metric, value in metrics.items():
-        print(f"{metric}: {value:0.3f}")
+    print(metrics)
 
 
 if __name__ == "__main__":
