@@ -2,10 +2,10 @@
 import pytest
 
 # Local imports
-from sageworks.transforms.data_to_data.light.data_to_data_light import DataToDataLight
+from sageworks.core.transforms.data_to_data.light.data_to_data_light import DataToDataLight
 
 
-@pytest.mark.slow
+@pytest.mark.long
 def test():
     """Tests for the Data to Data (light) Transforms"""
 
